"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getW3cVerifiableCredentialInstance = exports.getW3cVerifiablePresentationInstance = exports.getSphereonW3cVerifiablePresentation = exports.getSphereonW3cVerifiableCredential = exports.getSphereonOriginalVerifiableCredential = void 0;
const utils_1 = require("../../../utils");
const vc_1 = require("../../vc");
const DifPresentationExchangeError_1 = require("../DifPresentationExchangeError");
function getSphereonOriginalVerifiableCredential(w3cVerifiableCredential) {
    if (w3cVerifiableCredential.claimFormat === vc_1.ClaimFormat.LdpVc) {
        return utils_1.JsonTransformer.toJSON(w3cVerifiableCredential);
    }
    else if (w3cVerifiableCredential.claimFormat === vc_1.ClaimFormat.JwtVc) {
        return w3cVerifiableCredential.serializedJwt;
    }
    else {
        throw new DifPresentationExchangeError_1.DifPresentationExchangeError(`Unsupported claim format. Only ${vc_1.ClaimFormat.LdpVc} and ${vc_1.ClaimFormat.JwtVc} are supported.`);
    }
}
exports.getSphereonOriginalVerifiableCredential = getSphereonOriginalVerifiableCredential;
function getSphereonW3cVerifiableCredential(w3cVerifiableCredential) {
    if (w3cVerifiableCredential.claimFormat === vc_1.ClaimFormat.LdpVc) {
        return utils_1.JsonTransformer.toJSON(w3cVerifiableCredential);
    }
    else if (w3cVerifiableCredential.claimFormat === vc_1.ClaimFormat.JwtVc) {
        return w3cVerifiableCredential.serializedJwt;
    }
    else {
        throw new DifPresentationExchangeError_1.DifPresentationExchangeError(`Unsupported claim format. Only ${vc_1.ClaimFormat.LdpVc} and ${vc_1.ClaimFormat.JwtVc} are supported.`);
    }
}
exports.getSphereonW3cVerifiableCredential = getSphereonW3cVerifiableCredential;
function getSphereonW3cVerifiablePresentation(w3cVerifiablePresentation) {
    if (w3cVerifiablePresentation instanceof vc_1.W3cJsonLdVerifiablePresentation) {
        return utils_1.JsonTransformer.toJSON(w3cVerifiablePresentation);
    }
    else if (w3cVerifiablePresentation instanceof vc_1.W3cJwtVerifiablePresentation) {
        return w3cVerifiablePresentation.serializedJwt;
    }
    else {
        throw new DifPresentationExchangeError_1.DifPresentationExchangeError(`Unsupported claim format. Only ${vc_1.ClaimFormat.LdpVc} and ${vc_1.ClaimFormat.JwtVc} are supported.`);
    }
}
exports.getSphereonW3cVerifiablePresentation = getSphereonW3cVerifiablePresentation;
function getW3cVerifiablePresentationInstance(w3cVerifiablePresentation) {
    if (typeof w3cVerifiablePresentation === 'string') {
        return vc_1.W3cJwtVerifiablePresentation.fromSerializedJwt(w3cVerifiablePresentation);
    }
    else {
        return utils_1.JsonTransformer.fromJSON(w3cVerifiablePresentation, vc_1.W3cJsonLdVerifiablePresentation);
    }
}
exports.getW3cVerifiablePresentationInstance = getW3cVerifiablePresentationInstance;
function getW3cVerifiableCredentialInstance(w3cVerifiableCredential) {
    if (typeof w3cVerifiableCredential === 'string') {
        return vc_1.W3cJwtVerifiableCredential.fromSerializedJwt(w3cVerifiableCredential);
    }
    else {
        return utils_1.JsonTransformer.fromJSON(w3cVerifiableCredential, vc_1.W3cJsonLdVerifiableCredential);
    }
}
exports.getW3cVerifiableCredentialInstance = getW3cVerifiableCredentialInstance;
//# sourceMappingURL=transform.js.map